@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef __AKONADI_SERIALIZER_ADDRESSEE_H__
-#define __AKONADI_SERIALIZER_ADDRESSEE_H__
+#pragma once
 
 #include <QObject>
 
@@ -36,4 +35,3 @@ private:
 };
 }
 
-#endif
