@@ -6,8 +6,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_CONTACTGROUPEDITOR_P_H
-#define AKONADI_CONTACTGROUPEDITOR_P_H
+#pragma once
 
 #include "contactgroupeditor.h"
 
@@ -53,4 +52,3 @@ public:
 };
 }
 
-#endif
