@@ -6,8 +6,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_CONTACTGROUPEDITORDELEGATE_P_H
-#define AKONADI_CONTACTGROUPEDITORDELEGATE_P_H
+#pragma once
 
 #include <QLineEdit>
 
@@ -65,4 +64,3 @@ private:
 };
 }
 
-#endif
