@@ -7,8 +7,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_EMAILADDRESSSELECTIONWIDGET_H
-#define AKONADI_EMAILADDRESSSELECTIONWIDGET_H
+#pragma once
 
 #include "akonadi-contact_export.h"
 
@@ -112,4 +111,3 @@ private:
 };
 }
 
-#endif
